#include <AI8051U.H>
#include "UART1.h"

bit		busy;			//串口忙标志
char	wptr;			//写指针
char	rptr;			//读指针
char	buffer[16];		//接受缓存，长度16


/**
  * @brief  串口1初始化
  * @param  无
  * @retval 无
  */
void Uart1_Init(void)			//UART1初始化
{
	SCON = 0x50;		//模式1（8位数据）、接受使能
	AUXR |= 0x01;		//串口1选择定时器2为波特率发生器
	AUXR |= 0x04;		//定时器时钟1T模式
	TL2 = BRT;			//波特率对应的重载值
	TH2 = BRT >> 8;
	AUXR |= 0x10;		//定时器2开始计时
	PS = 0;				//串口1中断优先级
	//ES = 1;			//使能串口1中断
	//EA = 1;			//使能总中断
	
	wptr = 0x00;		//清零写指针
	rptr = 0x00;		//清零读指针
	busy = 0;			//清零忙指针
}

/**
  * @brief  串口1发送一个字符
  * @param  dat 要发送的一个字符
  * @retval 无
  */
void Uart1_Send(char dat)		//发送字符函数
{
	while (busy);		//当串口忙，等待
	busy = 1;			//忙标志置1
	SBUF = dat;			//发送数据dat
}

/**
  * @brief  串口1发送一个字符串
  * @param  *p 要发送的一个字符串
  * @retval 无
  */
void Uart1_SendStr(char *p)	//发送字符串函数
{
	while (*p)			//字符串结束前‘\0’前循环
	{
		Uart1_Send(*p++);	//逐个发送字符串的字符
	}
}

/*串口中断函数模板
void Uart1_Isr(void) interrupt 4
{
	if (TI)						//发送中断标志置1时
	{
		TI = 0;					//清零发送中断标志
		busy = 0;				//清零忙状态
	}
	if (RI)						//接收中断标志置1时
	{
		RI = 0;					//清零接收中断标志
		buffer[wptr++] = SBUF;	//接受长度16
		wptr &= 0x0f;			//接受长度16
	}
}
*/